cd "C:\Users\[FILENAME]\Study1"
clear
set more off
insheet using "YouGovData.csv", names

* Demographics
gen d_age=2020-birthyr
label var d_age "Age in years"

gen d_female=gender=="Female"
label var d_female "Female (1=yes)"

gen d_black=race=="Black"
gen d_hispanic=race=="Hispanic"
label var d_black "Black (1=yes)"
label var d_hispanic "Hispanic (1=yes)"

gen d_educ=.
replace d_educ=0 if educ4=="High school or less"
replace d_educ=1 if educ4=="Some college"
replace d_educ=2 if educ4=="College grad"
replace d_educ=3 if educ4=="Postgrad"
label var d_educ "Education scale (0-3)"
label define d_educlab 0 "HS" 1 "Some College" 2 "College" 3 "Postgrad"
label values d_educ d_educlab

*2016 and 2018 turnout
gen voted_2016=vote2016=="Yes"
label var voted_2016 "Voted in 2016 (1=yes)"
gen voted_2018=vote2018=="Yes"
label var voted_2018 "Voted in 2018 (1=yes)"

*generic covid worry
gen own_covidworry=.
replace own_covidworry=0 if covid_worry_self==`"Not worried at all"'
replace own_covidworry=1 if covid_worry_self==`"A little bit worried"'
replace own_covidworry=2 if covid_worry_self==`"Somewhat worried"'
replace own_covidworry=3 if covid_worry_self==`"Extremely worried"'
label var own_covidworry "General worry about COVID-19"
label define worrylab 0 "Not at all" 1 "A little" 2 "Somewhat" 3 "Extremely worried"
label values own_covidworry worrylab

* use these variables for pid
tab pid7_with_leaners pid7

* code up 7point pid
gen pid_7cat = .
replace pid_7cat = 1 if pid7=="Strong Democrat"
replace pid_7cat = 2 if pid7=="Not very strong Democrat"
replace pid_7cat = 3 if pid7=="Lean Democrat"
replace pid_7cat = 4 if pid7=="Independent" | pid7=="Not sure"
replace pid_7cat = 5 if pid7=="Lean Republican"
replace pid_7cat = 6 if pid7=="Not very strong Republican"
replace pid_7cat = 7 if pid7=="Strong Republican"

label var pid_7cat "Partisanship 7 point scale (1=Strong Dem., 7=Strong Rep.)"
label define lab_pid7cat 1 "Strong Dem." 2 "Weak Dem." 3 "Lean Dem." 4 "Independent" 5 "Lean Rep." 6 "Weak Rep." 7 "Strong Rep."
label values pid_7cat lab_pid7cat

tab pid_7cat, gen(dummypid_)
label var dummypid_1 "Strong Democrat"
label var dummypid_2 "Not very strong Democrat"
label var dummypid_3 "Lean Democrat"
label var dummypid_4 "Independent"
label var dummypid_5 "Lean Republican"
label var dummypid_6 "Not very strong Republican"
label var dummypid_7 "Strong Republican"

rename pid3_condensed pid3_nolean
label var pid3_nolean "Partisanship, no leaners"
rename pid7_with_leaners  pid3_withlean
label var pid3_withlean "Partisanship, with leaners"

* party of registration
tab party_reg

label define yesnolab 0 "No" 1 "Yes" 

* Voted in primary, among those eligible
gen prim20_amongeligvoted=.
replace prim20_amongeligvoted=1 if vote2020primary=="Yes"
replace prim20_amongeligvoted=0 if vote2020primary=="No"
label values prim20_amongeligvoted yesnolab
label var prim20_amongeligvoted "Among elig., voted in primary"

* Primary, among those who voted
gen prim20_votemode=.
replace prim20_votemode=1 if vote2020_prefer==`"By mail/absentee ballot"'
replace prim20_votemode=2 if vote2020_prefer==`"In person at a polling place on Election Day"'
label define primvotemodelab 1 "Mail" 2 "In person"
label values prim20_votemode primvotemodelab
label var prim20_votemode "Mode of voting primary"

gen prim20_howreturnmail=.
replace prim20_howreturnmail=1 if how_return_ballot==`"By mail"'
replace prim20_howreturnmail=2 if how_return_ballot==`"I dropped it in my town/city's designated drop off box"' 
label define howreturnmaillab 1 "Mail" 2 "In person"
label values prim20_howreturnmail howreturnmaillab
label var prim20_howreturnmail "How return primary mail ballot"

label define agreelab 0 "Strongly Disagree" 1 "Somewhat disagree" 2 "Neutral" 3 "Somewhat agree" 4 "Strongly Agree"
gen prim20_perceivedcovidsafety = .
replace prim20_perceivedcovidsafety = 0 if in_person_covid_risk=="Strongly disagree"
replace prim20_perceivedcovidsafety = 1 if in_person_covid_risk=="Somewhat disagree"
replace prim20_perceivedcovidsafety = 2 if in_person_covid_risk=="Neither agree nor disagree"
replace prim20_perceivedcovidsafety = 3 if in_person_covid_risk=="Somewhat agree"
replace prim20_perceivedcovidsafety = 4 if in_person_covid_risk=="Strongly agree"
label var prim20_perceivedcovidsafety "Agree primary polling place safe from COVID"
label values prim20_perceivedcovidsafety agreelab

gen prim20_alsorequestmail=.
replace prim20_alsorequestmail=1 if also_request_mail=="Yes"
replace prim20_alsorequestmail=0 if also_request_mail=="No"
label values prim20_alsorequestmail yesnolab
label var prim20_alsorequestmail "If voted in person, request mail ballot? (1=yes)"

foreach var of varlist why_in_person_1-why_in_person_5 {
	gen pprim20_`var'=.
	replace pprim20_`var'=1 if `var'=="selected"
	replace pprim20_`var'=0 if `var'=="not selected"
	label values pprim20_`var' yesnolab
	}
label var pprim20_why_in_person_1 "Prim Not Return Mail Ballot: Mail ballot never arrived"
label var pprim20_why_in_person_2 "Prim Not Return Mail Ballot: Mail ballot arrived too late"
label var pprim20_why_in_person_3 "Prim Not Return Mail Ballot: Waited too long to fill out mail ballot"
label var pprim20_why_in_person_4 "Prim Not Return Mail Ballot: Worried about USPS"
label var pprim20_why_in_person_5 "Prim Not Return Mail Ballot: Worried vote not counted"

* Same thing for people who requested mail ballots but didn't vote

* November 2020 vote
gen nov20_turnout = .
replace nov20_turnout = 0 if votenov2020=="Extremely unlikely to vote"
replace nov20_turnout = 1 if votenov2020=="Somewhat unlikely"
replace nov20_turnout = 2 if votenov2020=="Neither likely nor unlikely"
replace nov20_turnout = 3 if votenov2020=="Somewhat likely"
replace nov20_turnout = 4 if votenov2020=="Extremely likely to vote"
label var nov20_turnout "Nov. 2020 turnout intention (0-4)"
lab define likely_lab 0 "V. Unlikely" 1 "S. Unlikely" 2 "Neutral" 3 "S. Likely" 4 "V. Likely"
label values nov20_turnout likely_lab

gen nov20_prefermode = .
replace nov20_prefermode = 1 if  votenov2020prefer== "By mail/absentee ballot" 
replace nov20_prefermode = 2 if  votenov2020prefer== "In person at a polling place on Election Day" 
replace nov20_prefermode = 3 if  votenov2020prefer== "Not sure" 
label var nov20_prefermode "Nov. 2020 prefered voting method"
label define nov20_preferlab 1 "Mail" 2 "Polling place" 3 "Not Sure"
label values nov20_prefermode nov20_preferlab

gen nov20_endupmode = .
replace nov20_endupmode = 1 if  vote_expecthow== "By mail/absentee ballot" 
replace nov20_endupmode = 2 if  vote_expecthow== "In person at the polls on Election Day" 
replace nov20_endupmode = 3 if  vote_expecthow== `"I probably won't end up voting"'
label var nov20_endupmode "Nov. 2020 how end up voting"
label define nov2020enduplab 1 "Mail" 2 "Polling place" 3 "Not Vote"
label values nov20_endupmode nov2020enduplab

gen nov20_wouldvoteinperson = .
replace nov20_wouldvoteinperson = 0 if notpreferred_show_up=="Extremely unlikely to vote in person"
replace nov20_wouldvoteinperson = 1 if notpreferred_show_up=="Somewhat unlikely to vote in person"
replace nov20_wouldvoteinperson = 2 if notpreferred_show_up=="Neither likely nor unlikely"
replace nov20_wouldvoteinperson = 3 if notpreferred_show_up=="Somewhat likely to vote in person"
replace nov20_wouldvoteinperson = 4 if notpreferred_show_up=="Extremely likely to vote in person"
label var nov20_wouldvoteinperson "If want mail, likelihood vote in person if have to?"
label values nov20_wouldvoteinperson likely_lab

gen nov20_requestmailballot=.
replace nov20_requestmailballot = 0 if mail_request_likelihood== `"I am very unlikely to request a mail ballot (0-10% chance)"'
replace nov20_requestmailballot = 1 if mail_request_likelihood== `"I might request a mail ballot (11-39% chance)"'
replace nov20_requestmailballot = 2 if mail_request_likelihood== `"It is a toss-up (40-60% chance)"'
replace nov20_requestmailballot = 3 if mail_request_likelihood== `"I’m probably going to request a mail ballot (61-90% chance)"'
replace nov20_requestmailballot = 4 if mail_request_likelihood== `"I am very likely to request a mail ballot (91-100% chance)"'
label var nov20_requestmailballot "Likelihood request mail ballot"
lab define requestliklab 0 "0-10%" 1 "11-39%" 2 "40-60%" 3 "61-90%" 4 "91-100%"
label values nov20_requestmailballot requestliklab

gen nov20_votecount_mail=.
replace nov20_votecount_mail = 0 if votecounted_mail== `"Extremely unlikely to be counted"'
replace nov20_votecount_mail = 1 if votecounted_mail== `"Somewhat unlikely"'
replace nov20_votecount_mail = 2 if votecounted_mail== `"Neither likely nor unlikely"'
replace nov20_votecount_mail = 3 if votecounted_mail== `"Somewhat likely"'
replace nov20_votecount_mail = 4 if votecounted_mail== `"Extremely likely to be counted"' 
label var nov20_votecount_mail "Likelihood mail vote counted"
label values nov20_votecount_mail likely_lab

gen nov20_votecount_person=.
replace nov20_votecount_person = 0 if votecounted_person== `"Extremely unlikely to be counted"'
replace nov20_votecount_person = 1 if votecounted_person== `"Somewhat unlikely"'
replace nov20_votecount_person = 2 if votecounted_person== `"Neither likely nor unlikely"'
replace nov20_votecount_person = 3 if votecounted_person== `"Somewhat likely"'
replace nov20_votecount_person = 4 if votecounted_person== `"Extremely likely to be counted"' 
label var nov20_votecount_person "Likelihood in person vote counted"
label values nov20_votecount_person likely_lab

gen nov20_votefraud_mail=.
replace nov20_votefraud_mail = 0 if votefraud_mail== `"Extremely unlikely to lead to fraud"'
replace nov20_votefraud_mail = 1 if votefraud_mail== `"Somewhat unlikely"'
replace nov20_votefraud_mail = 2 if votefraud_mail== `"Neither likely nor unlikely"'
replace nov20_votefraud_mail = 3 if votefraud_mail== `"Somewhat likely"'
replace nov20_votefraud_mail = 4 if votefraud_mail== `"Extremely likely to lead to fraud"'
label var nov20_votefraud_mail "Likelihood mail vote leads to fraud"
label values nov20_votefraud_mail likely_lab

gen nov20_votefraud_person=.
replace nov20_votefraud_person = 0 if votefraud_person== `"Extremely unlikely to lead to fraud"'
replace nov20_votefraud_person = 1 if votefraud_person== `"Somewhat unlikely"'
replace nov20_votefraud_person = 2 if votefraud_person== `"Neither likely nor unlikely"'
replace nov20_votefraud_person = 3 if votefraud_person== `"Somewhat likely"'
replace nov20_votefraud_person = 4 if votefraud_person== `"Extremely likely to lead to fraud"'
label var nov20_votefraud_person "Likelihood in person vote leads to fraud"
label values nov20_votefraud_person likely_lab

gen nov20_votecovid_mail=.
replace nov20_votecovid_mail = 0 if votecovidrisk_mail== `"Not at all worried"'
replace nov20_votecovid_mail = 1 if votecovidrisk_mail== `"A little bit worried"'
replace nov20_votecovid_mail = 2 if votecovidrisk_mail== `"Somewhat worried"'
replace nov20_votecovid_mail = 3 if votecovidrisk_mail== `"Very worried"'
label define worry_lab 0 "Not at all" 1 "A little" 2 "Somewhat" 3 "Very"
label var nov20_votecovid_mail "Worry mail voting leads to covid-19"
label values nov20_votecovid_mail worry_lab

gen nov20_votecovid_person=.
replace nov20_votecovid_person = 0 if votecovidrisk_person== `"Not at all worried"'
replace nov20_votecovid_person = 1 if votecovidrisk_person== `"A little bit worried"'
replace nov20_votecovid_person = 2 if votecovidrisk_person== `"Somewhat worried"'
replace nov20_votecovid_person = 3 if votecovidrisk_person== `"Very worried"'
label var nov20_votecovid_person "Worry in person voting leads to covid-19"
label values nov20_votecovid_person worry_lab

gen nov20_voteifsafetyprecautions = .
replace nov20_voteifsafetyprecautions = 0 if voteifstepstaken=="Extremely unlikely"
replace nov20_voteifsafetyprecautions = 1 if voteifstepstaken=="Somewhat unlikely"
replace nov20_voteifsafetyprecautions = 2 if voteifstepstaken=="Neither likely nor unlikely"
replace nov20_voteifsafetyprecautions = 3 if voteifstepstaken=="Somewhat likely"
replace nov20_voteifsafetyprecautions = 4 if voteifstepstaken=="Extremely likely"
label var nov20_voteifsafetyprecautions "Would vote if safety precautions taken"
label values nov20_voteifsafetyprecautions likely_lab

foreach var of varlist worry_travel worry_inline worry_nearworkers worry_touchpen worry_nearothers worry_doorhandles {
	gen nov20_`var'=.
	replace nov20_`var' = 0 if `var'== `"Not at all worried"'
	replace nov20_`var' = 1 if `var'== `"A little bit worried"'
	replace nov20_`var' = 2 if `var'== `"Somewhat worried"'
	replace nov20_`var' = 3 if `var'== `"Very worried"'
	label values nov20_`var' worry_lab
	tab nov20_`var'
	}
	
label var nov20_worry_travel "Covid-19: Worry about travel to polls"
label var nov20_worry_inline  "Covid-19: Worry about waiting in line"
label var nov20_worry_nearworkers "Covid-19: Worry about being near pollworkers"
label var nov20_worry_touchpen "Covid-19: Worry about shared voting equipment"
label var nov20_worry_nearothers "Covid-19: Worry about near others when filling out ballot"
label var nov20_worry_doorhandles "Covid-19: Worry about door handles"

*scale these polling place worries 
gen nov20_worryscale = nov20_worry_doorhandles + nov20_worry_inline + nov20_worry_nearothers + nov20_worry_touchpen + nov20_worry_travel + nov20_worry_nearworkers
replace nov20_worryscale = nov20_worryscale/18

label define importancelab 0 "Not at all" 1 "Not very" 2 "Somewhat" 3 "Very Important"
foreach var of varlist addressconcerns1_workerppe addressconcerns1_sixfeet addressconcerns1_workersymptoms addressconcerns1_workersmasked addressconcerns1_boothsdistanced addressconcerns1_discardtouch addressconcerns1_exitenterdoors addressconcerns1_sticker addressconcerns1_safetydoc {
	local name=substr("`var'",18,100)
	gen nov20_impt_`name'=.
	replace nov20_impt_`name'  = 0 if `var'=="Not at all important"
	replace nov20_impt_`name'  = 1 if `var'=="Not very important"
	replace nov20_impt_`name'  = 2 if `var'=="Somewhat important" 
	replace nov20_impt_`name'  = 3 if `var'=="Very important"
	label values nov20_impt_`name' importancelab
	}

label var nov20_impt_workerppe "Importance: Masks and hand sanitizer available"
label var nov20_impt_sixfeet "Importance: Wait 6 feet part in marked boxes"
label var nov20_impt_workersymptoms "Importance: Poll workers checked for symptoms"
label var nov20_impt_workersmasked "Importance: Poll workers masked"
label var nov20_impt_boothsdistanced "Importance: Polls socially distanced"
label var nov20_impt_discardtouch "Importance: Shared equipment cleaned/discarded between use"
label var nov20_impt_exitenterdoors "Importance: Separate entrance/exits"
label var nov20_impt_sticker "Importance: Get I voted sticker"
label var nov20_impt_safetydoc "Importance: Mailed document about polling place safety"

gen nov20_cfsafetyturnout = .
replace nov20_cfsafetyturnout = 0 if voteifstepstaken=="Extremely unlikely"
replace nov20_cfsafetyturnout = 1 if voteifstepstaken=="Somewhat unlikely"
replace nov20_cfsafetyturnout = 2 if voteifstepstaken=="Neither likely nor unlikely"
replace nov20_cfsafetyturnout = 3 if voteifstepstaken=="Somewhat likely"
replace nov20_cfsafetyturnout = 4 if voteifstepstaken=="Extremely likely"
label var nov20_cfsafetyturnout "Nov. 2020 in person voting if impt. safety steps taken (0-4)"
label values nov20_cfsafetyturnout likely_lab

*code it from 0 to 1 for interpretability
gen nov20_turnoutifsafe = nov20_cfsafetyturnout/4

local ctr=1
foreach var of varlist groups_* {
	gen nov20_endorse_`ctr'=.
	replace nov20_endorse_`ctr'=1 if `var'=="selected"
	replace nov20_endorse_`ctr'=0 if `var'=="not selected"
	label values nov20_endorse_`ctr' yesnolab
	local ctr=`ctr'+1
	}

label var nov20_endorse_1 "Prefered endorser: A statewide panel of doctors and nurses"
label var nov20_endorse_2 "Prefered endorser: A panel of doctors and nurses from your community"
label var nov20_endorse_3 "Prefered endorser: Local election officials"
label var nov20_endorse_4 "Prefered endorser: Local elected officials, like your mayor"
label var nov20_endorse_5 "Prefered endorser: Local public health officers, like the department of public health"
label var nov20_endorse_6 "Prefered endorser: State election officials"
label var nov20_endorse_7 "Prefered endorser: State elected officials, like the governor"
label var nov20_endorse_8 "Prefered endorser: State public health officials"

label define trustlab 0 "Not much" 1 "A little" 2 "Somewhat" 3 "A great deal"
local ctr=1
foreach var of varlist groupstrust_* {
	gen nov20_trust_`ctr'=.
	replace nov20_trust_`ctr'=0 if `var'=="Not much/Not at all"
	replace nov20_trust_`ctr'=1 if `var'=="A little bit"
	replace nov20_trust_`ctr'=2 if `var'=="Somewhat"
	replace nov20_trust_`ctr'=3 if `var'=="A great deal"
	label values nov20_trust_`ctr' trustlab
	local ctr=`ctr'+1
	}

label var nov20_trust_1 "Trust endorser: A statewide panel of doctors and nurses"
label var nov20_trust_2 "Trust endorser: A panel of doctors and nurses from your community"
label var nov20_trust_3 "Trust endorser: Local election officials"
label var nov20_trust_4 "Trust endorser: Local elected officials, like your mayor"
label var nov20_trust_5 "Trust endorser: Local public health officers, like the department of public health"
label var nov20_trust_6 "Trust endorser: State election officials"
label var nov20_trust_7 "Trust endorser: State elected officials, like the governor"
label var nov20_trust_8 "Trust endorser: State public health officials"

foreach var of varlist nov20_trust* {
	codebook `var'
	tab `var'
	}

foreach var of varlist mailfears_* {
	gen nov20_`var'=.
	replace nov20_`var' = 0 if `var'== "Not worried at all"
	replace nov20_`var' = 1 if `var'== `"A little bit worried"'
	replace nov20_`var' = 2 if `var'== `"Somewhat worried"'
	replace nov20_`var' = 3 if `var'== `"Very worried"'
	label values nov20_`var' worry_lab
}

label var nov20_mailfears_appreceived "Mail worry: Application successful"
label var nov20_mailfears_ballottime "Mail worry: Ballot reach me in time"
label var nov20_mailfears_returntime "Mail worry: Ballot returned in time"
label var nov20_mailfears_countornot "Mail worry: Officials choose to count"
label var nov20_mailfears_postage "Mail worry: Having postage"
label var nov20_mailfears_fraud "Mail worry: Someone request or intercepts my ballot"
label var nov20_mailfears_loseballot "Mail worry: How vote if spoil or lose ballot"
label var nov20_mailfears_changemind "Mail worry: How vote if I decide I want to vote in person"

foreach var of varlist addressmailfears_* {
	gen nov20_`var'=.
	replace nov20_`var'  = 0 if `var'=="Not at all important"
	replace nov20_`var'  = 1 if `var'=="Not very important"
	replace nov20_`var'  = 2 if `var'=="Somewhat important" 
	replace nov20_`var'  = 3 if `var'=="Very important"
	label values nov20_`var' importancelab
	}

label var nov20_addressmailfears_verify "Importance mail concern: Verify receipt of ballot"
label var nov20_addressmailfears_postage "Importance mail concern: Postage not required"
label var nov20_addressmailfears_instruct"Importance mail concern: Clear instructions"
label var nov20_addressmailfears_dropoff "Importance mail concern: Could drop off ballot"
label var nov20_addressmailfears_30days "Importance mail concern: Request 30 days before election"

gen ever_somethinggotteninway =.
replace ever_somethinggotteninway=1 if  vote_distract=="Yes"
replace ever_somethinggotteninway=0 if  vote_distract=="No"
label var ever_somethinggotteninway "Something every distracted you from voting despite planning to?"
label values ever_somethinggotteninway yesnolab

gen areyouaplanner=.
replace areyouaplanner=1 if  planner==`"I'm the sort of person who plans ahead"'
replace areyouaplanner=0 if  planner==`"I'm the sort of person who figures things out at the last moment"'
label var areyouaplanner "Do you plan ahead?"
label values areyouaplanner yesnolab

* In primary, among those who voted, observed difference in way of voting
tab prim20_votemode [aweight=weight]
tab pid3_withlean prim20_votemode [aweight=weight], row

*** Start code for worries
foreach var of varlist votecovidrisk_* {
	gen nov20_`var'=.
	replace nov20_`var'  = 0 if `var'=="Not at all worried"
	replace nov20_`var'  = 1 if `var'=="A little bit worried"
	replace nov20_`var'  = 2 if `var'=="Somewhat worried" 
	replace nov20_`var'  = 3 if `var'=="Very worried"
	label values nov20_`var' worrylab
	}

encode pid3_withlean, gen(party_3cat)
label def p3 1 "Democrat" 2 "Independent" 3 "Republican"
label val party_3cat p3
label var party_3cat "PID including leaners"
	
gen income_5cat = 0 
replace income_5cat = 1 if faminc5 == "Less Than $30,000"
replace income_5cat = 2 if faminc5 == "$30,000 - $59,999"
replace income_5cat = 3 if faminc5 == "$60,000 - $99,999"
replace income_5cat = 4 if faminc5 == "$100,000 - $149,999"
replace income_5cat = 5 if faminc5 == "$150,000+"

label def inc 0 "Prefer Not to Say" 1  "Less Than $30,000" 2  "$30,000 - $59,999" 3  "$60,000 - $99,999" 4  "$100,000 - $149,999" 5  "$150,000+"
label val income_5cat inc

* Basic descriptive results
set scheme s1color

*binarize prefered mode of voting
gen nov20_preferinperson = (nov20_prefermode == 2)
gen nov20_prefermail = (nov20_prefermode ==1)
gen nov20_endupinperson = (nov20_endupmode == 2)
tab nov20_prefermode

svyset [pweight=weight]

* Footnote 4 comment about 2018 and 2016 turnout among sample
table [pweight=weight], stat(mean voted_2016 voted_2018)

* Appendix Table A1, which is weighted summary statistics
preserve
label var income_5cat "Income"
label var pid_7 "Partisanship"
label var d_educ "Education"
table [pweight=weight], stat(mean d_age d_female d_black d_hispanic i.income_5cat i.d_educ i.pid_7 ) nformat("%4.2f")
table [pweight=weight], stat(sd d_age  )
table [pweight=weight], stat(n d_age d_female d_black d_hispanic i.income_5cat i.d_educ i.pid_7 )
restore

* Main text: Preferred mode of voting, overall and by PID with leaners
table [pweight=weight], stat(mean nov20_preferinperson nov20_prefermail)
table party_3cat [pweight=weight], stat(mean nov20_preferinperson nov20_prefermail)
* without leaners
table pid3_nolean  [pweight=weight], stat(mean nov20_preferinperson nov20_prefermail)

* Footnote 5: Vote less likely to be counted by mail
gen lesslikelycountedmail= nov20_votecount_person>nov20_votecount_mail if nov20_votecount_mail~=. & nov20_votecount_person~=.
table [pweight=weight], stat(mean lesslikelycountedmail)
table party_3cat [pweight=weight], stat(mean lesslikelycountedmail)

* Main text: Worry about COVID risk, page 10
svy: tabulate nov20_votecovid_person
svy: tabulate nov20_votecovid_mail

svy: tabulate party_3cat nov20_votecovid_person, row
* Democrat to Republican ratio for very/somewhat
disp (.3053+.1974)/(.1449+.1194)
* No leaners
svy: tabulate pid3_nolean nov20_votecovid_person, row
disp (.2947+.198)/(.1714+.1479)

/*
Figure 1
*/

* Proportion somewhat or very worried for each thing (Panel A)
* Importance of Polling Place Safety Measures (Panel B)

* Figure 1A
preserve

	foreach var of varlist nov20_worry_inline nov20_worry_nearothers nov20_worry_touchpen nov20_worry_nearworkers nov20_worry_doorhandles nov20_worry_travel {
		rename `var' temp
		* Make sure scored so that you get top two categories
		gen `var' = (temp==2) | (temp==3) if temp~=.
		drop temp
	}

	label var nov20_worry_travel "Travel to polls"
	label var nov20_worry_inline  "Waiting in line"
	label var nov20_worry_nearworkers "Near pollworkers"
	label var nov20_worry_touchpen "Shared equipment"
	label var nov20_worry_nearothers "Near others in voting booth"
	label var nov20_worry_doorhandles "Door handles"

	local ctr=1
	gen outcome=""
	gen overall=.
	gen dem=.
	gen rep=.

	foreach var of varlist nov20_worry_inline nov20_worry_nearothers nov20_worry_touchpen nov20_worry_nearworkers nov20_worry_doorhandles nov20_worry_travel {
		local templabel : var label `var'
		replace outcome = "`templabel'" in `ctr'
		svy: mean `var'		
		matrix a = r(table)
		replace overall=a[1,1] in `ctr'
		svy: mean `var' if pid3_withlean=="Democrat" 
		matrix a = r(table)
		replace dem=a[1,1] in `ctr'
		svy: mean `var' if pid3_withlean=="Republican" 
		matrix a = r(table)
		replace rep=a[1,1] in `ctr'
		local ctr=`ctr'+1
		}
	
	keep outcome overall dem rep 
	drop if outcome==""
	
	label var overall "Overall"
	label var dem "Democrats"
	label var rep "Republicans"
	
	* raw data
	gen piddif=dem-rep

	cl
	
	graph hbar (asis) overall dem rep, over(outcome, sort(overall) descending) legend(rows(1)) bar(1, fcolor(black) bcolor(black)) bar(2, fcolor(blue) bcolor(blue)) bar(3, fcolor(red) bcolor(red)) title(Panel A: Worries About Voting in Person) scale(.75) name(Figure1_PanelA, replace) ytitle(Proportion Very or Somewhat Worried) ytitle(, size(small)) ylabel(0(.1).6)
restore

* Figure 1B
preserve

	foreach var of varlist nov20_impt_workerppe nov20_impt_sixfeet nov20_impt_workersymptoms nov20_impt_workersmasked nov20_impt_boothsdistanced nov20_impt_discardtouch nov20_impt_exitenterdoors nov20_impt_safetydoc {
		rename `var' temp
		gen `var' = (temp==3) if temp~=.
		drop temp
	}

	label var nov20_impt_workerppe "PPE and sanitizer available"
	label var nov20_impt_sixfeet "Voters stay six feet apart"
	label var nov20_impt_workersymptoms  "Poll workers symptom-free"
	label var nov20_impt_workersmasked "Workers masked"
	label var nov20_impt_boothsdistanced "Voting booths socially distanced"
	label var nov20_impt_discardtouch "Near others in voting booth"
	label var nov20_impt_safetydoc "Receive safety plan before election"
	label var nov20_impt_exitenterdoors "Enter and exit different doors"
	
	local ctr=1
	gen outcome=""
	gen overall=.
	gen dem=.
	gen rep=.

	foreach var of varlist nov20_impt_workerppe nov20_impt_sixfeet nov20_impt_workersymptoms nov20_impt_workersmasked nov20_impt_boothsdistanced nov20_impt_discardtouch nov20_impt_exitenterdoors nov20_impt_safetydoc {
		local templabel : var label `var'
		replace outcome = "`templabel'" in `ctr'
		svy: mean `var'		
		matrix a = r(table)
		replace overall=a[1,1] in `ctr'
		svy: mean `var' if pid3_withlean=="Democrat" 
		matrix a = r(table)
		replace dem=a[1,1] in `ctr'
		svy: mean `var' if pid3_withlean=="Republican" 
		matrix a = r(table)
		replace rep=a[1,1] in `ctr'
		local ctr=`ctr'+1
		}
	
	keep outcome overall dem rep 
	drop if outcome==""
	
	label var overall "Overall"
	label var dem "Democrats"
	label var rep "Republicans"
	
	* raw data
	gen piddif=dem-rep

	cl
	
	graph hbar (asis) overall dem rep, over(outcome, sort(overall) descending) legend(rows(1)) bar(1, fcolor(black) bcolor(black)) bar(2, fcolor(blue) bcolor(blue)) bar(3, fcolor(red) bcolor(red)) title(Panel B: Importance of Polling Place Safety Measures) scale(.75) name(Figure1_PanelB, replace) ytitle(Proportion Rating Very Important) ytitle(, size(small)) ylabel(0(.1)1)
restore

graph combine Figure1_PanelA Figure1_PanelB, cols(1) name(Figure1, replace)
graph export Figures\Figure1.pdf, replace

****
*Appendix version of figure 1, no leaners
****

* Proportion somewhat or very worried for each thing

* Figure A1A
preserve

	foreach var of varlist nov20_worry_inline nov20_worry_nearothers nov20_worry_touchpen nov20_worry_nearworkers nov20_worry_doorhandles nov20_worry_travel {
		rename `var' temp
		* Make sure scored so that you get top two categories
		gen `var' = (temp==2) | (temp==3) if temp~=.
		drop temp
	}

	label var nov20_worry_travel "Travel to polls"
	label var nov20_worry_inline  "Waiting in line"
	label var nov20_worry_nearworkers "Near pollworkers"
	label var nov20_worry_touchpen "Shared equipment"
	label var nov20_worry_nearothers "Near others in voting booth"
	label var nov20_worry_doorhandles "Door handles"

	local ctr=1
	gen outcome=""
	gen overall=.
	gen dem=.
	gen rep=.

	foreach var of varlist nov20_worry_inline nov20_worry_nearothers nov20_worry_touchpen nov20_worry_nearworkers nov20_worry_doorhandles nov20_worry_travel {
		local templabel : var label `var'
		replace outcome = "`templabel'" in `ctr'
		svy: mean `var'		
		matrix a = r(table)
		replace overall=a[1,1] in `ctr'
		svy: mean `var' if pid3_nolean=="Democrat"
		matrix a = r(table)
		replace dem=a[1,1] in `ctr'
		svy: mean `var' if pid3_nolean=="Republican"
		matrix a = r(table)
		replace rep=a[1,1] in `ctr'
		local ctr=`ctr'+1
		}
	
	keep outcome overall dem rep 
	drop if outcome==""
	
	label var overall "Overall"
	label var dem "Democrats"
	label var rep "Republicans"
	
	gen piddif=dem-rep
	
	cl
	
	graph hbar (asis) overall dem rep, over(outcome, sort(overall) descending) legend(rows(1)) bar(1, fcolor(black) bcolor(black)) bar(2, fcolor(blue) bcolor(blue)) bar(3, fcolor(red) bcolor(red)) title(Panel A: Worries About Voting in Person) scale(.75) name(NoLeanFigure1_PanelA, replace) ytitle(Proportion Very or Somewhat Worried) ytitle(, size(small)) ylabel(0(.1).6) note("Leaners coded as independents.")

restore

* Figure A1B
preserve

	foreach var of varlist nov20_impt_workerppe nov20_impt_sixfeet nov20_impt_workersymptoms nov20_impt_workersmasked nov20_impt_boothsdistanced nov20_impt_discardtouch nov20_impt_exitenterdoors nov20_impt_safetydoc {
		rename `var' temp
		gen `var' = (temp==3) if temp~=.
		drop temp
	}

	label var nov20_impt_workerppe "PPE and sanitizer available"
	label var nov20_impt_sixfeet "Voters stay six feet apart"
	label var nov20_impt_workersymptoms  "Poll workers symptom-free"
	label var nov20_impt_workersmasked "Workers masked"
	label var nov20_impt_boothsdistanced "Voting booths socially distanced"
	label var nov20_impt_discardtouch "Near others in voting booth"
	label var nov20_impt_safetydoc "Receive safety plan before election"
	label var nov20_impt_exitenterdoors "Enter and exit different doors"
	
	local ctr=1
	gen outcome=""
	gen overall=.
	gen dem=.
	gen rep=.

	foreach var of varlist nov20_impt_workerppe nov20_impt_sixfeet nov20_impt_workersymptoms nov20_impt_workersmasked nov20_impt_boothsdistanced nov20_impt_discardtouch nov20_impt_exitenterdoors nov20_impt_safetydoc {
		local templabel : var label `var'
		replace outcome = "`templabel'" in `ctr'
		svy: mean `var'		
		matrix a = r(table)
		replace overall=a[1,1] in `ctr'
		svy: mean `var' if pid3_nolean=="Democrat"
		matrix a = r(table)
		replace dem=a[1,1] in `ctr'
		svy: mean `var' if pid3_nolean=="Republican"
		matrix a = r(table)
		replace rep=a[1,1] in `ctr'
		local ctr=`ctr'+1
		}
	
	keep outcome overall dem rep 
	drop if outcome==""
	
	label var overall "Overall"
	label var dem "Democrats"
	label var rep "Republicans"
	
	gen piddif=dem-rep

	cl
	
	graph hbar (asis) overall dem rep, over(outcome, sort(overall) descending) legend(rows(1)) bar(1, fcolor(black) bcolor(black)) bar(2, fcolor(blue) bcolor(blue)) bar(3, fcolor(red) bcolor(red)) title(Panel B: Importance of Polling Place Safety Measures) scale(.75) name(NoLeanFigure1_PanelB, replace) ytitle(Proportion Rating Very Important) ytitle(, size(small)) ylabel(0(.1)1) note("Leaners coded as independents.")
	*graph export Figures\NoLeanFigure1_PanelB.pdf, replace
restore

graph combine NoLeanFigure1_PanelA NoLeanFigure1_PanelB, cols(1) name(AppendixFigure1, replace)
graph export Figures\AppendixFigure1.pdf, replace

* Regression analysis, Table 1.

gen covidinpersonworryscale = nov20_votecovid_person/3
label var covidinpersonworryscale "Worry about COVID from in-person voting scale (0-1)"

eststo clear
*Prefer in person, no party weighted 
eststo: reg nov20_preferinperson covidinpersonworryscale d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
table [pweight=weight] if e(sample), stat(mean covidinpersonworryscale)  stat(sd covidinpersonworryscale)  stat(min covidinpersonworryscale)  stat(max covidinpersonworryscale)
table [pweight=weight] if e(sample), stat(mean nov20_preferinperson)  stat(sd nov20_preferinperson)  stat(min nov20_preferinperson)  stat(max nov20_preferinperson)
*Prefer in person, with party weighted
eststo: reg nov20_preferinperson covidinpersonworryscale ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust

*end up voting outcome, no party, weighted
eststo: reg nov20_endupinperson covidinpersonworryscale d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
table [pweight=weight] if e(sample), stat(mean nov20_endupinperson)  stat(sd nov20_endupinperson)  stat(min nov20_endupinperson)  stat(max nov20_endupinperson)
*end up in person, with party, weighted
eststo: reg nov20_endupinperson covidinpersonworryscale ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*vote if safety precautions are taken, no party, weighted
eststo: reg nov20_turnoutifsafe covidinpersonworryscale d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
table [pweight=weight] if e(sample), stat(mean nov20_turnoutifsafe)  stat(sd nov20_turnoutifsafe)  stat(min nov20_turnoutifsafe)  stat(max nov20_turnoutifsafe)
*vote if safety precuations are taken, with party, weighted
eststo: reg nov20_turnoutifsafe covidinpersonworryscale ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust

esttab using "Tables\Table1.csv", b(2) se(2) r2(2) alignment(c) refcat(1.d_educ "Education" 1.income_5cat "Income", nolab) order(covidinpersonworryscale 1.party_3cat 3.party_3cat)  nobaselevels long compress label replace 

* Logit version of table 1
eststo clear
*Prefer in person, no party weighted 
eststo: logit nov20_preferinperson covidinpersonworryscale d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*Prefer in person, with party weighted
eststo: logit nov20_preferinperson covidinpersonworryscale ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*end up voting outcome, no party, weighted
eststo: logit nov20_endupinperson covidinpersonworryscale d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*end up in person, with party, weighted
eststo: logit nov20_endupinperson covidinpersonworryscale ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*vote if safety precautions are taken, no party, weighted
eststo: ologit nov20_turnoutifsafe covidinpersonworryscale d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*vote if safety precuations are taken, with party, weighted
eststo: ologit nov20_turnoutifsafe covidinpersonworryscale ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust

esttab using "Tables\Table1_MLE.csv", b(2) se(2) r2(2) alignment(c) refcat(1.d_educ "Education" 1.income_5cat "Income", nolab) order(covidinpersonworryscale 1.party_3cat 3.party_3cat)  nobaselevels long compress label replace 
eststo clear

* Categorical indicators for worries version Table 1.
*Prefer in person, no party weighted 
eststo: reg nov20_preferinperson i.nov20_votecovid_person d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*Prefer in person, with party weighted
eststo: reg nov20_preferinperson i.nov20_votecovid_person ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*end up voting outcome, no party, weighted
eststo: reg nov20_endupinperson i.nov20_votecovid_person d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*end up in person, with party, weighted
eststo: reg nov20_endupinperson i.nov20_votecovid_person ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*vote if safety precautions are taken, no party, weighted
eststo: reg nov20_turnoutifsafe i.nov20_votecovid_person d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust
*vote if safety precuations are taken, with party, weighted
eststo: reg nov20_turnoutifsafe i.nov20_votecovid_person ib4.pid_7cat d_age d_female d_black d_hisp i.d_educ i.income_5cat [pweight = weight],  robust

esttab using "Tables\Table1_CategoricalIV.csv", b(2) se(2) r2(2) alignment(c) refcat(1.d_educ "Education" 1.income_5cat "Income", nolab) order(nov20_votecovid_person 1.party_3cat 3.party_3cat) nobaselevels long compress label replace 
eststo clear

